@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 # shortcuts
 #  os and distros
@@ -429,6 +429,13 @@ sub mapping {
       [like_debian,
        [package => 'freecdb']]],
 
+     [cpanmod => 'Ceph::Rados',
+      #[os_freebsd,
+      # [package => 'ceph-devel']], # XXX Doesnt build for FreeBSD 10.x
+      [like_debian,
+       [package => 'librados-dev']],
+     ],
+
      [cpanmod => 'Chipcard::PCSC',
       # XXX what about freebsd?
       [like_debian,
@@ -1838,6 +1845,13 @@ sub mapping {
        [package => 'libesmtp-devel']],
      ],
 
+     [cpanmod => 'Net::Gadu',
+      [os_freebsd,
+       [package => 'pl-libgadu']],
+      [like_debian,
+       [package => 'libgadu-dev']],
+     ],
+
      [cpanmod => 'Net::Ifstat',
       [os_freebsd,
        [package => 'ifstat']],
@@ -2119,9 +2133,11 @@ sub mapping {
       # XXX what about freebsd?
       [like_debian,
        [linuxdistrocodename => [qw(squeeze wheezy jessie precise xenial)],
-	[package => [qw(libx11-dev libxpm-dev libgif-dev libpng12-dev libjpeg-dev), 'pkg-config | pkgconf']]], # XXX maybe also add libtiff...
-       [package => [qw(libx11-dev libxpm-dev libgif-dev libpng-dev libjpeg-dev), 'pkg-config | pkgconf']], # XXX maybe also add libtiff...
+	[package => [qw(libx11-dev libxcursor-dev libxpm-dev libgif-dev libpng12-dev libjpeg-dev), 'pkg-config | pkgconf']]], # XXX maybe also add libtiff...
+       [package => [qw(libx11-dev libxcursor-dev libxpm-dev libgif-dev libpng-dev libjpeg-dev), 'pkg-config | pkgconf']], # XXX maybe also add libtiff...
       ],
+      [like_fedora,
+       [package => [qw(libXcursor-devel)]]], # XXX probably incomplete
      ],
 
      [cpanmod => 'PulseAudio',
@@ -2224,6 +2240,16 @@ sub mapping {
       [like_debian,
        [package => 'libosp-dev']]],
 
+     ## version mismatch
+     #[cpanmod => 'SNMP',
+     # [os_freebsd,
+     #  [package => 'net-snmp']],
+     # [like_debian,
+     #  [package => 'libsnmp-dev']],
+     # [like_fedora,
+     #  [package => 'net-snmp-devel']],
+     #],
+
      [cpanmod => 'SNMP::OID::Translate',
       [os_freebsd,
        [package => 'net-snmp']],
@@ -2306,7 +2332,10 @@ sub mapping {
       # XXX what about freebsd?
       [like_debian,
        # tcllib is needed for the snit package
-       [package => ['tk8.5-dev', 'tcllib']]]],
+       [package => ['tk8.5-dev', 'tcllib']]],
+      [like_fedora,
+       [package => ['tk', 'tcllib']]],
+     ],
 
      [cpanmod => 'Template::Plugin::React',
       [os_freebsd,
